@@ -176,6 +176,14 @@ typedef enum
   G_DESKTOP_TOUCHPAD_HANDEDNESS_MOUSE
 } GDesktopTouchpadHandedness;
 
+typedef enum
+{
+  G_DESKTOP_TOUCHPAD_CLICK_METHOD_DEFAULT,
+  G_DESKTOP_TOUCHPAD_CLICK_METHOD_NONE,
+  G_DESKTOP_TOUCHPAD_CLICK_METHOD_AREAS,
+  G_DESKTOP_TOUCHPAD_CLICK_METHOD_FINGERS
+} GDesktopTouchpadClickMethod;
+
 typedef enum
 {
   G_DESKTOP_DEVICE_SEND_EVENTS_ENABLED,
